require "numru/ggraph"
require "./gp_dcpam_const_v1.0"
require "./gp_dcpam_methods_v1.0"
include NumRu

DaysInAYear = DaysOfMonth.sum


pardir="."

vname = "SurfTemp"
cntmin = 200.0 ; cntmax = 320.0
vname = "SurfAlbedo"
cntmin =   0.0 ; cntmax =   0.6


if ARGV.size == 3 then
  pardir = ARGV[1]
  vname  = ARGV[2]
else
  print "Unexpected number of arguments: ", ARGV.size, "\n"
  exit
end

case vname
when "SurfTemp" then
  cntmin = 200.0 ; cntmax = 320.0
when "SurfAlbedo" then
  cntmin =   0.0 ; cntmax =   0.6
when "Rain", "Snow", "PRCP" then
  cntmin =   0.0 ; cntmax =   1.5e-4
else
  print "Unexpected vname: ", vname, "\n"
  exit
end


ncfn = pardir+"/????/"+vname+"_rank??????.nc"
url = ncfn + "@" + vname
gphys = GPhys::IO.open_gturl( url )

def runmean2d( gp, meanwidth )

  va_time_in = gp.coord('time')
  na_time_in = va_time_in.val
  tmax_in    = na_time_in.size

  tmax_out = tmax_in/meanwidth

  gpout = gp[true,true,0..(tmax_out-1)].copy

  na_time_out = gpout.coord('time').val

  for i in 0..(tmax_out-1)
    na_time_out[i] = na_time_in[meanwidth*i..meanwidth*(i+1)-1].mean
    gpout[true,true,i] = gp.cut('time'=>na_time_in[meanwidth*i]..na_time_in[meanwidth*(i+1)-1]).mean('time')
  end

  va_time_out = VArray.new( na_time_out,
                           { "long_name"=>va_time_in.long_name,
                             "units"=>va_time_in.units.to_s }, "time" )
  gpout.axis('time').set_pos(va_time_out)

  return gpout

end

def convtimeunit( gp )

  va_time_in = gp.coord('time')
  na_time_in = va_time_in.val
  na_time_in = na_time_in / ( 360.0 * 24 * 60 )
  va_time_out = VArray.new( na_time_in,
                           { "long_name"=>va_time_in.long_name,
                             "units"=>"years" }, "time" )
  gp.axis('time').set_pos(va_time_out)

  return gp

end

#gpout = gphys.mean('lon')
#gpout = gpout.running_mean('time',365*4,bc=GPhys::BC_TRIM)

#gpout = runmean2d( gphys, 360*4 )
#gpout = convtimeunit( gpout )

va_time_in = gphys.coord('time')
na_time_in = va_time_in.val
ntime = na_time_in.size
gphys = gphys.cut('time'=>na_time_in[-DaysInAYear*DataNumOfDay]..na_time_in[-1])
gpout = time_interval_mean( gphys, DataNumOfDay*1 )
na_time_out = gpout.coord('time').val - na_time_in[-DaysInAYear*DataNumOfDay]
replace_axis(
  gpout, "time",
  "time", va_time_in.long_name, va_time_in.units.to_s, na_time_out )

gpout = gpout.mean('lon')


iws = (ARGV[0] || (puts ' WORKSTATION ID (I)  ? ;'; DCL::sgpwsn; gets)).to_i
DCL.gropn(iws)

#DCL.sldiv('y',1,4)
DCL.sgpset('isub', 96)     # control character of subscription: '_' --> '`'
DCL.sgpset('lfull',true)
DCL.uzfact(0.6)            # font size
DCL.sgpset('lclip', true)  # clip graph
DCL.glpset('lmiss',true)   # missing value

#DCL.sgscmn(4)  # blue-cyan-white-yellow-red
#DCL.sgscmn(5)  # gray-scale
#DCL.sgscmn(14) # blue-white-red

#levels = [110,120,130,140,150,160,170,180,190,200,210,220,230,240]
#patterns = [10999,15999,20999,25999,30999,35999,40999,50999,60999,65999,70999,75999,80999,90999,95999]

GGraph.set_axes('ylabelint'=>30)
GGraph.set_fig 'itr'=> 1, 'viewport'=>[0.1,0.9,0.1,0.6], 'window'=>[gpout.coord('time').val[0].ceil,gpout.coord('time').val[-1].ceil,-90,90]

GGraph.tone    gpout, true , 'exchange'=>true,
               'nlev'=>15, 'keep'=>true
#               'min'=>cntmin, 'max'=>cntmax #, 'lev'=>levels, 'pat'=>patterns
GGraph.contour gpout, false, 'exchange'=>true,
               'nlev'=>15, 'keep'=>true
#               'min'=>cntmin, 'max'=>cntmax #, 'lev'=>levels
GGraph.color_bar

DCL.grcls
